@@ -29,9 +29,9 @@ class Plot3dAssistant : public Cantor::Assistant
     Plot3dAssistant( QObject* parent, QList<QVariant> args );
     ~Plot3dAssistant();
 
-    void initActions();
+    void initActions() Q_DECL_OVERRIDE;
     
-    QStringList run(QWidget* parentt);
+    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
     
 };
 
