@@ -25,7 +25,6 @@
 #include <QVariant>
 #include <KXMLGUIClient>
 #include <KPluginInfo>
-#include <KUrl>
 
 #include "cantor_export.h"
 
@@ -98,7 +97,7 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      */
     virtual Capabilities capabilities() const = 0;
     /**
-     * Returns wether all of this backends requirements are fulfiled, or if some are missing.
+     * Returns whether all of this backends requirements are fulfiled, or if some are missing.
      * @return @c true if all the requirements needed to use this Backend are fulfilled
      * @return @c false some requirements are missing. e.g. the maxima executable can not be found
      * @see Capablility
@@ -112,12 +111,19 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      */
     virtual QString id() const = 0;
 
+    /**
+     * Returns the recommended version of the backend supported by Cantor
+     * @return the recommended version of the backend
+     */
+    virtual QString version() const;
+
     //Stuff extracted from the .desktop file
     /**
      * Returns the name of the backend
      * @return the backends name
      */
     QString name() const;
+
     /**
      * Returns a short comment about the backend.
      * @return comment about the backend
@@ -141,10 +147,10 @@ class CANTOR_EXPORT Backend : public QObject, public KXMLGUIClient
      *   "http://docs.kde.org/stable/en/kdeedu/kalgebra/");
      * @return Url of the help
      */
-    virtual KUrl helpUrl() const;
+    virtual QUrl helpUrl() const;
     /**
      * Returns if the backend should be enabled (shown in the Backend dialog)
-     * @return @c true, if the enabled flag is set to true, and the requirements are fullfilled
+     * @return @c true, if the enabled flag is set to true, and the requirements are fulfiled
      * @return @c false, if the backend was purposedly disabled, or requirements are missing
      * @see requirementsFullfilled()
      */
